@@ -1,4 +1,19 @@
 #!/usr/bin/env python2
+import string
+import sys
+from xml.dom import Node
+try:
+    from xml.ns import XMLNS
+except ImportError:
+    class XMLNS(object):
+        BASE = "http://www.w3.org/2000/xmlns/"
+        XML = "http://www.w3.org/XML/1998/namespace"
+
+try:
+    from io import StringIO
+except ImportError:
+    from cStringIO import StringIO
+
 '''XML Canonicalization
 
 Patches Applied to xml.dom.ext.c14n:
@@ -47,34 +62,37 @@ or
   http://www.w3.org/Consortium/Legal/copyright-software-19980720
 '''
 
-import string
-from xml.dom import Node
-try:
-    from xml.ns import XMLNS
-except:
-    class XMLNS:
-        BASE = "http://www.w3.org/2000/xmlns/"
-        XML = "http://www.w3.org/XML/1998/namespace"
 
-try:
-    from io import StringIO
-except ImportError:
-    from cStringIO import StringIO
+def _attrs(E):
+    return (E.attributes and list(E.attributes.values())) or []
 
-_attrs = lambda E: (E.attributes and list(E.attributes.values())) or []
-_children = lambda E: E.childNodes or []
-_IN_XML_NS = lambda n: n.name.startswith("xmlns")
-_inclusive = lambda n: n.unsuppressedPrefixes is None
+
+def _children(E):
+    return E.childNodes or []
+
+
+def _IN_XML_NS(n):
+    return n.name.startswith("xmlns")
+
+
+def _inclusive(n):
+    return n.unsuppressedPrefixes is None
 
 
 # Does a document/PI has lesser/greater document order than the
 # first element?
 _LesserElement, _Element, _GreaterElement = list(range(3))
 
+if sys.version_info[0] > 2:
+    def cmp(a, b):
+        return (a > b) - (a < b)
+
 
 def _sorter(n1, n2):
     '''_sorter(n1,n2) -> int
-    Sorting predicate for non-NS attributes.'''
+
+    Sorting predicate for non-NS attributes.
+    '''
 
     i = cmp(n1.namespaceURI, n2.namespaceURI)
     if i:
@@ -84,7 +102,9 @@ def _sorter(n1, n2):
 
 def _sorter_ns(n1, n2):
     '''_sorter_ns((n,v),(n,v)) -> int
-    "(an empty namespace URI is lexicographically least)."'''
+
+    "(an empty namespace URI is lexicographically least)."
+    '''
 
     if n1[0] == 'xmlns':
         return -1
@@ -95,7 +115,9 @@ def _sorter_ns(n1, n2):
 
 def _utilized(n, node, other_attrs, unsuppressedPrefixes):
     '''_utilized(n, node, other_attrs, unsuppressedPrefixes) -> boolean
-    Return true if that nodespace is utilized within the node'''
+
+    Return true if that nodespace is utilized within the node
+    '''
     if n.startswith('xmlns:'):
         n = n[6:]
     elif n.startswith('xmlns'):
@@ -117,8 +139,10 @@ def _utilized(n, node, other_attrs, unsuppressedPrefixes):
 
 def _inclusiveNamespacePrefixes(node, context, unsuppressedPrefixes):
     '''http://www.w3.org/TR/xml-exc-c14n/
+
     InclusiveNamespaces PrefixList parameter, which lists namespace prefixes that
-    are handled in the manner described by the Canonical XML Recommendation'''
+    are handled in the manner described by the Canonical XML Recommendation
+    '''
     inclusive = []
     if node.prefix:
         usedPrefixes = ['xmlns:%s' % node.prefix]
@@ -146,14 +170,19 @@ def _inclusiveNamespacePrefixes(node, context, unsuppressedPrefixes):
 
     return inclusive, unused_namespace_dict
 
-#_in_subset = lambda subset, node: not subset or node in subset
-_in_subset = lambda subset, node: subset is None or node in subset  # rich's tweak
+
+# _in_subset = lambda subset, node: not subset or node in subset
+def _in_subset(subset, node):
+    return subset is None or node in subset  # rich's tweak
 
 
-class _implementation:
+class _implementation(object):
 
-    '''Implementation class for C14N. This accompanies a node during it's
-    processing and includes the parameters and processing state.'''
+    '''Implementation class for C14N.
+
+    This accompanies a node during it's
+    processing and includes the parameters and processing state.
+    '''
 
     # Handler for each node type; populated during module instantiation.
     handlers = {}
@@ -187,9 +216,11 @@ class _implementation:
 
     def _inherit_context(self, node):
         '''_inherit_context(self, node) -> list
+
         Scan ancestors of attribute and namespace context.  Used only
         for single element node canonicalization, not for subset
-        canonicalization.'''
+        canonicalization.
+        '''
 
         # Collect the initial list of xml:foo attributes.
         xmlattrs = list(filter(_IN_XML_NS, _attrs(node)))
@@ -207,9 +238,11 @@ class _implementation:
 
     def _do_document(self, node):
         '''_do_document(self, node) -> None
+
         Process a document node. documentOrder holds whether the document
         element has been encountered such that PIs/comments can be written
-        as specified.'''
+        as specified.
+        '''
 
         self.documentOrder = _LesserElement
         for child in node.childNodes:
@@ -229,8 +262,10 @@ class _implementation:
 
     def _do_text(self, node):
         '''_do_text(self, node) -> None
+
         Process a text or CDATA node.  Render various special characters
-        as their C14N entity representations.'''
+        as their C14N entity representations.
+        '''
         if not _in_subset(self.subset, node):
             return
         s = string.replace(node.data, "&", "&amp;")
@@ -244,6 +279,7 @@ class _implementation:
 
     def _do_pi(self, node):
         '''_do_pi(self, node) -> None
+
         Process a PI node. Render a leading or trailing #xA if the
         document order of the PI is greater or lesser (respectively)
         than the document element.
@@ -266,6 +302,7 @@ class _implementation:
 
     def _do_comment(self, node):
         '''_do_comment(self, node) -> None
+
         Process a comment node. Render a leading or trailing #xA if the
         document order of the comment is greater or lesser (respectively)
         than the document element.
@@ -285,7 +322,9 @@ class _implementation:
 
     def _do_attr(self, n, value):
         ''''_do_attr(self, node) -> None
-        Process an attribute.'''
+
+        Process an attribute.
+        '''
 
         W = self.write
         W(' ')
@@ -302,7 +341,9 @@ class _implementation:
 
     def _do_element(self, node, initial_other_attrs=[], unused=None):
         '''_do_element(self, node, initial_other_attrs = [], unused = {}) -> None
-        Process an element (and its children).'''
+
+        Process an element (and its children).
+        '''
 
         # Get state (from the stack) make local copies.
         #   ns_parent -- NS declarations in parent
@@ -332,17 +373,18 @@ class _implementation:
                     n = "xmlns"        # DOM bug workaround
                 ns_local[n] = a.nodeValue
             elif a.namespaceURI == XMLNS.XML:
-                if inclusive or (in_subset and _in_subset(self.subset, a)):  # 020925 Test to see if attribute node in subset
+                # 020925 Test to see if attribute node in subset
+                if inclusive or (in_subset and _in_subset(self.subset, a)):
                     xml_attrs_local[a.nodeName] = a  # 0426
             else:
                 if _in_subset(self.subset, a):  # 020925 Test to see if attribute node in subset
                     other_attrs.append(a)
 
-#                # TODO: exclusive, might need to define xmlns:prefix here
+#                # exclusive, might need to define xmlns:prefix here
 #                if not inclusive and a.prefix is not None and not ns_rendered.has_key('xmlns:%s' %a.prefix):
 #                    ns_local['xmlns:%s' %a.prefix] = ??
 
-            #add local xml:foo attributes to ancestor's xml:foo attributes
+            # add local xml:foo attributes to ancestor's xml:foo attributes
             xml_attrs.update(xml_attrs_local)
 
         # Render the node
@@ -356,7 +398,7 @@ class _implementation:
                     prefix = 'xmlns'
 
                 if prefix not in ns_rendered and prefix not in ns_local:
-                    if not prefix in ns_unused_inherited:
+                    if prefix not in ns_unused_inherited:
                         raise RuntimeError('For exclusive c14n, unable to map prefix "%s" in %s' % (
                             prefix, node))
 
@@ -410,7 +452,8 @@ class _implementation:
             W('>')
 
         # Push state, recurse, pop state.
-        state, self.state = self.state, (ns_local, ns_rendered, xml_attrs, ns_unused_inherited)
+        state, self.state = self.state, (ns_local,
+                                         ns_rendered, xml_attrs, ns_unused_inherited)
         for c in _children(node):
             _implementation.handlers[c.nodeType](self, c)
         self.state = state
